@@ -23,12 +23,16 @@
 
 #include <X11/Xlib.h> /* for Display */
 #include <X11/Xmd.h> /* for CARD32 */
+#include <sys/types.h>
+#include <sys/socket.h>
 #include <netinet/in.h> /* for in_addr */
 
 typedef struct _GdmDisplay GdmDisplay;
 
 #include "gdm-net.h" /* for GdmConnection */
 
+#include "gdm.h" /* for GDM_CUSTOM_COMMAND_MAX */
+
 #define TYPE_STATIC 1		/* X server defined in GDM configuration */
 #define TYPE_XDMCP 2		/* Remote display/Xserver */
 #define TYPE_FLEXI 3		/* Local Flexi X server */
@@ -59,7 +63,7 @@ typedef enum {
 	GDM_LOGOUT_ACTION_REBOOT,
 	GDM_LOGOUT_ACTION_SUSPEND,
 	GDM_LOGOUT_ACTION_CUSTOM_CMD_FIRST,
-	GDM_LOGOUT_ACTION_CUSTOM_CMD_LAST,
+	GDM_LOGOUT_ACTION_CUSTOM_CMD_LAST = GDM_LOGOUT_ACTION_CUSTOM_CMD_FIRST + GDM_CUSTOM_COMMAND_MAX - 1,
 	GDM_LOGOUT_ACTION_LAST
 } GdmLogoutAction;
 
