@@ -95,6 +95,7 @@ static gint connection_type = 0;
 /* Exported for glade */
 void gdm_chooser_add_host (void);
 void gdm_chooser_add_entry_changed (void);
+void gdm_chooser_cancel (int sig);
 void gdm_chooser_manage (GtkButton *button, gpointer data);
 void gdm_chooser_browser_select (GtkWidget *widget,
 				 gint selected,
@@ -1961,6 +1962,14 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
+	/*
+	 * gdm_common_atspi_launch () needs gdk initialized.
+	 * We cannot start gtk before the registry is running
+	 * because the atk-bridge will crash.
+	 */
+	gdk_init (&argc, &argv);
+	gdm_common_atspi_launch ();
+
 	gtk_init (&argc, &argv);
 
 	ctx = g_option_context_new (_("- gdm login chooser")); 
@@ -1973,6 +1982,8 @@ main (int argc, char *argv[])
 	gdm_common_log_init ();
 	gdm_common_log_set_debug (gdm_config_get_bool (GDM_KEY_DEBUG));
 
+	gdm_common_setup_builtin_icons ();
+
 	/* Read all configuration at once, so the values get cached */
 	gdm_read_config ();
 
@@ -2052,7 +2063,7 @@ main (int argc, char *argv[])
 		return EXIT_SUCCESS;
 	}
     
-	gtk_window_set_default_icon_from_file (DATADIR"/pixmaps/gdm-xnest.png", NULL);
+	gtk_window_set_default_icon_name ("gdm-xnest");
 
 	gdm_chooser_gui_init ();
 	gdm_chooser_signals_init ();
